# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector.api.notifications_api import NotificationsApi  # noqa: E501


class TestNotificationsApi(unittest.IsolatedAsyncioTestCase):
    """NotificationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = NotificationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_notifications_get_user_notification_count(self) -> None:
        """Test case for notifications_get_user_notification_count

        Get user notification count  # noqa: E501
        """
        pass

    async def test_notifications_get_user_notifications(self) -> None:
        """Test case for notifications_get_user_notifications

        Get user notifications  # noqa: E501
        """
        pass

    async def test_notifications_mark_notifications_as_read(self) -> None:
        """Test case for notifications_mark_notifications_as_read

        Mark notifications as read  # noqa: E501
        """
        pass

    async def test_notifications_mark_notifications_as_read_internal(self) -> None:
        """Test case for notifications_mark_notifications_as_read_internal

        Mark notifications as read (internal)  # noqa: E501
        """
        pass

    async def test_notifications_send_notification(self) -> None:
        """Test case for notifications_send_notification

        Send notification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
