# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

class ContactFooterResponse(BaseModel):
    """
    ContactFooterResponse
    """
    footer: StrictStr = Field(...)
    is_override: StrictBool = Field(default=..., description="True if portal has custom footer, False if using weblate default")
    allowed_variables: conlist(StrictStr) = Field(...)
    __properties = ["footer", "is_override", "allowed_variables"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ContactFooterResponse:
        """Create an instance of ContactFooterResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ContactFooterResponse:
        """Create an instance of ContactFooterResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ContactFooterResponse.parse_obj(obj)

        _obj = ContactFooterResponse.parse_obj({
            "footer": obj.get("footer"),
            "is_override": obj.get("is_override"),
            "allowed_variables": obj.get("allowed_variables")
        })
        return _obj


